{% load staticfiles %}{% block top_of_page %}{% endblock %}
<!DOCTYPE html>
<!--[if lt IE 9]><html class="lte-ie8" lang="en"><![endif]-->
<!--[if gt IE 8]><!--><html lang="en"><!--<![endif]-->
  <head>
    <meta http-equiv="content-type" content="text/html; charset=UTF-8" />

    <title>{% block page_title %}{% endblock %}</title>

    <script type="text/javascript">
      (function(){if(navigator.userAgent.match(/IEMobile\/10\.0/)){var d=document,c="appendChild",a=d.createElement("style");a[c](d.createTextNode("@-ms-viewport{width:auto!important}"));d.getElementsByTagName("head")[0][c](a);}})();
    </script>

    <!--[if gt IE 8]><!--><link href="{% static 'stylesheets/govuk-template.css' %}" media="screen" rel="stylesheet" type="text/css" /><!--<![endif]-->
    <!--[if IE 6]><link href="{% static 'stylesheets/govuk-template-ie6.css' %}" media="screen" rel="stylesheet" type="text/css" /><![endif]-->
    <!--[if IE 7]><link href="{% static 'stylesheets/govuk-template-ie7.css' %}" media="screen" rel="stylesheet" type="text/css" /><![endif]-->
    <!--[if IE 8]><link href="{% static 'stylesheets/govuk-template-ie8.css' %}" media="screen" rel="stylesheet" type="text/css" /><![endif]-->

    <link href="{% static 'stylesheets/govuk-template-print.css' %}" media="print" rel="stylesheet" type="text/css" />

    <!--[if IE 8]>
    <script type="text/javascript">
      (function(){if(window.opera){return;}
       setTimeout(function(){var a=document,g,b={families:(g=
       ["nta"]),urls:["{% static 'stylesheets/fonts-ie8.css' %}"]},
       c="{% static 'javascripts/vendor/goog/webfont-debug.js' %}",d="script",
       e=a.createElement(d),f=a.getElementsByTagName(d)[0],h=g.length;WebFontConfig
       ={custom:b},e.src=c,f.parentNode.insertBefore(e,f);for(;h=h-1;a.documentElement
       .className+=' wf-'+g[h].replace(/\s/g,'').toLowerCase()+'-n4-loading');},0)
      })()
    </script>
    <![endif]-->
    <!--[if gte IE 9]><!-->
      <link href="{% static 'stylesheets/fonts.css' %}" media="all" rel="stylesheet" type="text/css" />
    <!--<![endif]-->


    <!--[if lt IE 9]>
      <script src="{% static 'javascripts/ie.js' %}" type="text/javascript"></script>
    <![endif]-->

    <link rel="shortcut icon" href="{% static 'images/favicon.ico' %}" type="image/x-icon" />

    <!-- For third-generation iPad with high-resolution Retina display: -->
    <link rel="apple-touch-icon-precomposed" sizes="144x144" href="{% static 'images/apple-touch-icon-144x144.png' %}">
    <!-- For iPhone with high-resolution Retina display: -->
    <link rel="apple-touch-icon-precomposed" sizes="114x114" href="{% static 'images/apple-touch-icon-114x114.png' %}">
    <!-- For first- and second-generation iPad: -->
    <link rel="apple-touch-icon-precomposed" sizes="72x72" href="{% static 'images/apple-touch-icon-72x72.png' %}">
    <!-- For non-Retina iPhone, iPod Touch, and Android 2.1+ devices: -->
    <link rel="apple-touch-icon-precomposed" href="{% static 'images/apple-touch-icon-57x57.png' %}">

    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta property="og:image" content="{% static 'images/opengraph-image.png' %}">

    <link href="{% static 'stylesheets/moj-template.css' %}" media="screen" rel="stylesheet" type="text/css" />

    {% block stylesheets %}{% endblock %}
    
    <!-- Google Analytics tracking -->
    <script>
      (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
      (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
      m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
      })(window,document,'script','//www.google-analytics.com/analytics.js','ga');

      ga('create', '{{ ga_id }}', 'service.gov.uk');
      
      ga('send', 'pageview');
    </script>
    
    {% block head %}{% endblock %}
  </head>

  <body class="{% block body_classes %}{{ product_type }} {{ phase }}{% endblock %}">
    <script type="text/javascript">document.body.className = ((document.body.className) ? document.body.className + ' js-enabled' : 'js-enabled');</script>

    <div id="skiplink-container">
      <div>
        <a href="#content" class="skiplink">Skip to main content</a>
      </div>
    </div>

    
    <header role="banner" id="global-header" class="{% if page.header_class %}{{ page.header_class }}{% endif %}">
      <div class="header-wrapper">
        <div class="header-global">
          <div class="header-logo">
            <a href="https://www.gov.uk/" title="Go to the GOV.UK homepage" id="logo" class="content">
              <img src="{% static 'images/gov.uk_logotype_crown.png' %}" alt=""> GOV.UK
            </a>
          </div>
          <div class="service-header">
            <a href="/" class="service-name">{{ proposition_title }}</a>
            <a href="https://www.gov.uk/service-manual/phases/{{ phase }}.html" class="service-phase {{ phase }}">{{ phase }}</a>
          </div>
          {% block inside_header %}{% endblock %}
        </div>
        {% block proposition_header %}{% endblock %}
      </div>
    </header>
    <!--end header-->
    

    <div class="indicator cf">
      <p>
        <strong>{{ phase }}:</strong>
        This is a new service -
        
          <a href="{{ feedback_url }}">your feedback</a>
        
        will help us to improve it
      </p>
    </div>

    {% block after_header %}{% endblock %}

    <div id="global-cookie-message">
      
        
        <p>GOV.UK uses cookies to make the site simpler. <a href="https://www.gov.uk/help/cookies">Find out more about cookies</a></p>
      
      
    </div>

    
    {% block before_content %}{% endblock %}

    <div id="wrapper" class="group">
      <section id="content" role="main">
        {% block content %}{% endblock %}
      </section>
    </div>
    

    <footer class="group js-footer" id="footer" role="contentinfo">

      <div class="footer-wrapper">
        {% block footer_top %}{% endblock %}

        <div class="footer-meta">
          <div class="footer-meta-inner">
            <h2 class="visuallyhidden">Support links</h2>
            <ul>
              <li><a href="http://www.gov.uk/support">Support</a></li>
              <li><a href="http://www.gov.uk/support/cookies">Cookies</a></li>
              <li><a href="http://www.gov.uk/feedback">Feedback</a></li>
              <li><a href="http://www.gov.uk/cymraeg">Cymraeg</a></li>
              <li>
                Built by the
                <a href="https://mojdigital.blog.gov.uk/"><abbr title="Ministry of Justice">MOJ</abbr> Digital Services</a>
              </li>
            </ul>

            <div class="open-government-licence">
              <h2><a href="http://www.nationalarchives.gov.uk/doc/open-government-licence/version/2">Open Government Licence</a></h2>
              <p>All content is available under the <a href="http://www.nationalarchives.gov.uk/doc/open-government-licence/version/2">Open Government Licence v2.0</a>, except where otherwise stated</p>
            </div>
          </div>

          <div class="copyright">
            <a href="http://www.nationalarchives.gov.uk/information-management/our-services/crown-copyright.htm">&copy; Crown copyright</a>
          </div>
        </div>
      </div>
    </footer>

    <!--end footer-->

    <div id="global-app-error" class="app-error hidden"></div>

    <script src="{% static 'javascripts/govuk-template.js' %}" type="text/javascript"></script>

    <!--[if gt IE 6]><!-->
    <script src="{% static 'javascripts/vendor/jquery/jquery-1.11.0.min.js' %}" type="text/javascript"></script>
    <script src="{% static 'javascripts/moj.js' %}" type="text/javascript"></script>

    {% block javascripts %}{% endblock %}

    <script type="text/javascript">$(moj.init);</script>
    <!--<![endif]-->

    {% block body_end %}{% endblock %}
  </body>
</html>
